==> blesta-5.10.2.zip: blesta/language/pt_br/admin_billing.php <==
<?php
/**
 * Admin Billing
 *
 * @package blesta
 * @subpackage blesta.language.pt_br
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminBilling.transactions.heading_number'] = 'Número';
$lang['AdminBilling.batch.text_batchsubmit'] = 'Processo em lote';
$lang['AdminBilling.batch.field_passphrase'] = 'Senha';
$lang['AdminBilling.batch.text_description'] = 'Digite sua senha para processar manualmente em lote todas as faturas programadas para débito automático com uma conta de pagamento armazenada localmente.';
$lang['AdminBilling.batch.no_passphrase'] = 'O processamento manual em lote não está habilitado.';
$lang['AdminBilling.batch.boxtitle_batch'] = 'Lote';
$lang['AdminBilling.batch.page_title'] = 'Lote de faturamento';
$lang['AdminBilling.printqueue.text_marksubmit'] = 'Marca impressa';
$lang['AdminBilling.printqueue.text_printsubmit'] = 'Imprimir';
$lang['AdminBilling.printqueue.heading_deliverydatesent'] = 'Data de envio';
$lang['AdminBilling.printqueue.heading_datedue'] = 'Data de vencimento';
$lang['AdminBilling.printqueue.heading_datebilled'] = 'Data do faturamento';
$lang['AdminBilling.printqueue.heading_due'] = 'Devido';
$lang['AdminBilling.printqueue.heading_paid'] = 'Pago';
$lang['AdminBilling.printqueue.heading_amount'] = 'Valor';
$lang['AdminBilling.printqueue.heading_client'] = 'Cliente #';
$lang['AdminBilling.printqueue.heading_invoice'] = 'Número da fatura';
$lang['AdminBilling.printqueue.no_results_to_print'] = 'Não há faturas na fila para serem impressas.';
$lang['AdminBilling.printqueue.no_results_printed'] = 'Não há faturas impressas anteriormente.';
$lang['AdminBilling.printqueue.boxtitle_printqueue'] = 'Fila de impressão';
$lang['AdminBilling.printqueue.category_printed'] = 'Anteriormente impresso';
$lang['AdminBilling.printqueue.category_to_print'] = 'Imprimir';
$lang['AdminBilling.printqueue.page_title'] = 'Fila de impressão de faturamento';
$lang['AdminBilling.invoices.text_edit'] = 'Editar';
$lang['AdminBilling.invoices.applied_no_results'] = 'Essa fatura não tem transações aplicadas a ela.';
$lang['AdminBilling.invoices.headingexpand_options'] = 'Opções';
$lang['AdminBilling.invoices.headingexpand_appliedon'] = 'Aplicado em';
$lang['AdminBilling.invoices.headingexpand_applied'] = 'Aplicado';
$lang['AdminBilling.transactions.heading_applied'] = 'Aplicado';
$lang['AdminBilling.transactions.heading_credit'] = 'Crédito';
$lang['AdminBilling.transactions.heading_amount'] = 'Valor';
$lang['AdminBilling.transactions.heading_type'] = 'Tipo';
$lang['AdminBilling.transactions.heading_client'] = 'Cliente #';
$lang['AdminBilling.invoices.headingexpand_amount'] = 'Valor';
$lang['AdminBilling.invoices.headingexpand_paymenttype'] = 'Tipo de pagamento';
$lang['AdminBilling.transactions.applied_no_results'] = 'Essa transação não foi aplicada a nenhuma fatura.';
$lang['AdminBilling.transactions.headingexpand_appliedon'] = 'Aplicado em';
$lang['AdminBilling.transactions.headingexpand_amount'] = 'Valor';
$lang['AdminBilling.transactions.headingexpand_invoice'] = 'Fatura';
$lang['AdminBilling.transactions.no_results'] = 'Não há transações com esse status.';
$lang['AdminBilling.transactions.option_edit'] = 'Editar';
$lang['AdminBilling.transactions.category_returned'] = 'Devolvido';
$lang['AdminBilling.transactions.category_refunded'] = 'Reembolsado';
$lang['AdminBilling.transactions.category_pending'] = 'Pendente';
$lang['AdminBilling.transactions.category_error'] = 'Erro';
$lang['AdminBilling.transactions.category_voided'] = 'Anulado';
$lang['AdminBilling.transactions.category_declined'] = 'Recusado';
$lang['AdminBilling.transactions.category_approved'] = 'Aprovado';
$lang['AdminBilling.transactions.heading_options'] = 'Opções';
$lang['AdminBilling.transactions.heading_date'] = 'Data';
$lang['AdminBilling.transactions.heading_reference_id'] = 'Referência';
$lang['AdminBilling.transactions.boxtitle_transactions'] = 'Transações';
$lang['AdminBilling.transactions.page_title'] = 'Transações de faturamento';
$lang['AdminBilling.serviceinfo.cancellation_reason'] = 'Motivo do cancelamento: %1$s';
$lang['AdminBilling.serviceinfo.no_results'] = 'Esse serviço não tem detalhes.';
$lang['AdminBilling.services.field_actionsubmit'] = 'Enviar';
$lang['AdminBilling.services.action.field_client'] = 'Cliente:';
$lang['AdminBilling.services.action.push_to_client'] = 'Enviar para o cliente';
$lang['AdminBilling.services.action.field_action_type_none'] = 'Não cancelar';
$lang['AdminBilling.services.action.field_action_type_date'] = 'Data específica';
$lang['AdminBilling.services.action.field_action_type_term'] = 'Fim do prazo';
$lang['AdminBilling.services.action.schedule_cancellation'] = 'Cancelamento de cronograma';
$lang['AdminBilling.services.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminBilling.services.no_results'] = 'Não há serviços com esse status.';
$lang['AdminBilling.services.text_never'] = 'Nunca';
$lang['AdminBilling.services.category_scheduled_cancellation'] = 'Programado';
$lang['AdminBilling.services.category_in_review'] = 'Em análise';
$lang['AdminBilling.services.category_pending'] = 'Pendente';
$lang['AdminBilling.services.category_suspended'] = 'Suspenso';
$lang['AdminBilling.services.category_canceled'] = 'Cancelado';
$lang['AdminBilling.services.category_active'] = 'Ativo';
$lang['AdminBilling.services.confirm_delete'] = 'Tem certeza de que deseja excluir esse serviço?';
$lang['AdminBilling.services.option_delete'] = 'Excluir';
$lang['AdminBilling.services.option_manage'] = 'Gerenciar';
$lang['AdminBilling.services.heading_options'] = 'Opções';
$lang['AdminBilling.services.heading_datecanceled'] = 'Data do cancelamento';
$lang['AdminBilling.services.heading_datesuspended'] = 'Data da suspensão';
$lang['AdminBilling.services.heading_daterenews'] = 'Data de renovação';
$lang['AdminBilling.services.heading_dateadded'] = 'Data de adição';
$lang['AdminBilling.services.heading_term'] = 'Prazo';
$lang['AdminBilling.services.heading_label'] = 'Rótulo';
$lang['AdminBilling.services.heading_package'] = 'Pacote';
$lang['AdminBilling.services.heading_client'] = 'Cliente #';
$lang['AdminBilling.services.boxtitle_services'] = 'Serviços';
$lang['AdminBilling.services.page_title'] = 'Serviços de faturamento';
$lang['AdminBilling.quotationinvoices.invoices_no_results'] = 'Não há faturas associadas a essa cotação.';
$lang['AdminBilling.quotationinvoices.option_view'] = 'Ver';
$lang['AdminBilling.quotationinvoices.headingexpand_options'] = 'Opções';
$lang['AdminBilling.quotationinvoices.headingexpand_date_billed'] = 'Data do faturamento';
$lang['AdminBilling.quotationinvoices.headingexpand_paid'] = 'Pago';
$lang['AdminBilling.quotationinvoices.headingexpand_amount'] = 'Valor';
$lang['AdminBilling.quotationinvoices.headingexpand_invoice'] = 'Número da fatura';
$lang['AdminBilling.quotations.no_results'] = 'Não há cotações com esse status.';
$lang['AdminBilling.quotations.confirm_approve'] = 'Tem certeza de que deseja aprovar essa citação?';
$lang['AdminBilling.quotations.option_approve'] = 'Aprovar';
$lang['AdminBilling.quotations.option_invoice'] = 'Criar fatura';
$lang['AdminBilling.quotations.option_view'] = 'Ver';
$lang['AdminBilling.quotations.option_edit'] = 'Editar';
$lang['AdminBilling.quotations.heading_options'] = 'Opções';
$lang['AdminBilling.quotations.heading_date_expires'] = 'Data de expiração';
$lang['AdminBilling.quotations.heading_date_created'] = 'Data de criação';
$lang['AdminBilling.quotations.heading_total'] = 'Valor';
$lang['AdminBilling.quotations.heading_subtotal'] = 'Subtotal';
$lang['AdminBilling.quotations.heading_staff'] = 'Citado por';
$lang['AdminBilling.quotations.heading_title'] = 'Título';
$lang['AdminBilling.quotations.heading_client'] = 'Cliente #';
$lang['AdminBilling.quotations.heading_quotation'] = 'Citação #';
$lang['AdminBilling.quotations.boxtitle_quotations'] = 'Citações';
$lang['AdminBilling.quotations.page_title'] = 'Cotações de faturamento';
$lang['AdminBilling.invoices.no_results'] = 'Não há faturas com esse status.';
$lang['AdminBilling.invoices.duration_infinite'] = '∞';
$lang['AdminBilling.invoices.duration_finite'] = '%1$s vezes';
$lang['AdminBilling.invoices.term_year_plural'] = '%1$s anos';
$lang['AdminBilling.invoices.term_month_plural'] = '%1$s meses';
$lang['AdminBilling.invoices.term_week_plural'] = '%1$s semanas';
$lang['AdminBilling.invoices.term_day_plural'] = '%1$s dias';
$lang['AdminBilling.invoices.term_year'] = '%1$s ano';
$lang['AdminBilling.invoices.term_month'] = '%1$s mês';
$lang['AdminBilling.invoices.term_week'] = '%1$s semana';
$lang['AdminBilling.invoices.term_day'] = '%1$s dia';
$lang['AdminBilling.invoices.subtotal_w_tax'] = '%1$s +taxas';
$lang['AdminBilling.invoices.option_pay'] = 'Pagamento';
$lang['AdminBilling.invoices.option_view'] = 'Ver';
$lang['AdminBilling.invoices.option_edit'] = 'Editar';
$lang['AdminBilling.invoices.category_recurring'] = 'Recorrente';
$lang['AdminBilling.invoices.category_pending'] = 'Pendente';
$lang['AdminBilling.invoices.category_pastdue'] = 'Vencido';
$lang['AdminBilling.invoices.category_voided'] = 'Anulado';
$lang['AdminBilling.invoices.category_closed'] = 'Fechado';
$lang['AdminBilling.invoices.category_drafts'] = 'Rascunhos';
$lang['AdminBilling.invoices.category_open'] = 'Aberto';
$lang['AdminBilling.invoices.heading_count'] = 'Contagem';
$lang['AdminBilling.invoices.heading_duration'] = 'Duração';
$lang['AdminBilling.invoices.heading_term'] = 'Prazo';
$lang['AdminBilling.invoices.heading_options'] = 'Opções';
$lang['AdminBilling.invoices.heading_datedue'] = 'Data de vencimento';
$lang['AdminBilling.invoices.heading_datebilled'] = 'Data do faturamento';
$lang['AdminBilling.invoices.heading_dateclosed'] = 'Data de fechamento';
$lang['AdminBilling.invoices.heading_due'] = 'Devido';
$lang['AdminBilling.invoices.heading_paid'] = 'Pago';
$lang['AdminBilling.invoices.heading_amount'] = 'Valor';
$lang['AdminBilling.invoices.heading_client'] = 'Cliente #';
$lang['AdminBilling.invoices.heading_recurinvoice'] = 'Recorrente #';
$lang['AdminBilling.invoices.heading_invoice'] = 'Número da fatura';
$lang['AdminBilling.invoices.boxtitle_invoices'] = 'Faturas';
$lang['AdminBilling.invoices.page_title'] = 'Faturas de cobrança';
$lang['AdminBilling.managewidgets.text_author'] = 'Autor:';
$lang['AdminBilling.managewidgets.text_version'] = 'ver %1$s';
$lang['AdminBilling.managewidgets.text_widgets'] = 'Arraste os widgets da direita para a esquerda para adicioná-los à sua visão geral de faturamento, ou da esquerda para a direita para removê-los.';
$lang['AdminBilling.updatedashboard.text_layout'] = 'Selecione um layout abaixo para personalizar sua visão geral de faturamento.';
$lang['AdminBilling.index.action_batch'] = 'Lote de itens pendentes';
$lang['AdminBilling.index.action_printqueue'] = 'Itens pendentes de impressão';
$lang['AdminBilling.index.no_actions'] = 'Não há itens de ação pendentes.';
$lang['AdminBilling.index.heading_actions'] = 'Itens de ação';
$lang['AdminBilling.index.customize_dashboard'] = 'Personalizar a visão geral';
$lang['AdminBilling.index.manage_widgets'] = 'Gerenciar Widgets';
$lang['AdminBilling.index.page_title'] = 'Visão geral do faturamento';
$lang['AdminBilling.index.closed_parethesis'] = ')';
$lang['AdminBilling.index.open_parethesis'] = '(';
$lang['AdminBilling.!error.future_cancel_date'] = 'A data de cancelamento programada não pode ser anterior.';
$lang['AdminBilling.!error.invalid_passphrase'] = 'A frase secreta inserida é inválida.';
$lang['AdminBilling.!error.no_invoices_selected'] = 'Nenhuma fatura foi selecionada.';
$lang['AdminBilling.!success.services_pushed'] = 'Os serviços selecionados foram enviados com sucesso para o novo cliente.';
$lang['AdminBilling.!success.services_scheduled_uncancel'] = 'Os serviços selecionados não estão mais programados para serem cancelados.';
$lang['AdminBilling.!success.services_scheduled_cancel'] = 'Os serviços selecionados foram programados com sucesso para serem cancelados.';
$lang['AdminBilling.!success.invoices_marked_printed'] = 'As faturas selecionadas foram marcadas como impressas.';

==> blesta-5.11.4.zip: blesta/language/pt_br/admin_billing.php <==
<?php
/**
 * Admin Billing
 *
 * @package blesta
 * @subpackage blesta.language.pt_br
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminBilling.transactions.heading_number'] = 'Número';
$lang['AdminBilling.batch.text_batchsubmit'] = 'Processo em lote';
$lang['AdminBilling.batch.field_passphrase'] = 'Senha';
$lang['AdminBilling.batch.text_description'] = 'Digite sua senha para processar manualmente em lote todas as faturas programadas para débito automático com uma conta de pagamento armazenada localmente.';
$lang['AdminBilling.batch.no_passphrase'] = 'O processamento manual em lote não está habilitado.';
$lang['AdminBilling.batch.boxtitle_batch'] = 'Lote';
$lang['AdminBilling.batch.page_title'] = 'Lote de faturamento';
$lang['AdminBilling.printqueue.text_marksubmit'] = 'Marca impressa';
$lang['AdminBilling.printqueue.text_printsubmit'] = 'Imprimir';
$lang['AdminBilling.printqueue.heading_deliverydatesent'] = 'Data de envio';
$lang['AdminBilling.printqueue.heading_datedue'] = 'Data de vencimento';
$lang['AdminBilling.printqueue.heading_datebilled'] = 'Data do faturamento';
$lang['AdminBilling.printqueue.heading_due'] = 'Devido';
$lang['AdminBilling.printqueue.heading_paid'] = 'Pago';
$lang['AdminBilling.printqueue.heading_amount'] = 'Valor';
$lang['AdminBilling.printqueue.heading_client'] = 'Cliente #';
$lang['AdminBilling.printqueue.heading_invoice'] = 'Número da fatura';
$lang['AdminBilling.printqueue.no_results_to_print'] = 'Não há faturas na fila para serem impressas.';
$lang['AdminBilling.printqueue.no_results_printed'] = 'Não há faturas impressas anteriormente.';
$lang['AdminBilling.printqueue.boxtitle_printqueue'] = 'Fila de impressão';
$lang['AdminBilling.printqueue.category_printed'] = 'Anteriormente impresso';
$lang['AdminBilling.printqueue.category_to_print'] = 'Imprimir';
$lang['AdminBilling.printqueue.page_title'] = 'Fila de impressão de faturamento';
$lang['AdminBilling.invoices.text_edit'] = 'Editar';
$lang['AdminBilling.invoices.applied_no_results'] = 'Essa fatura não tem transações aplicadas a ela.';
$lang['AdminBilling.invoices.headingexpand_options'] = 'Opções';
$lang['AdminBilling.invoices.headingexpand_appliedon'] = 'Aplicado em';
$lang['AdminBilling.invoices.headingexpand_applied'] = 'Aplicado';
$lang['AdminBilling.transactions.heading_applied'] = 'Aplicado';
$lang['AdminBilling.transactions.heading_credit'] = 'Crédito';
$lang['AdminBilling.transactions.heading_amount'] = 'Valor';
$lang['AdminBilling.transactions.heading_type'] = 'Tipo';
$lang['AdminBilling.transactions.heading_client'] = 'Cliente #';
$lang['AdminBilling.invoices.headingexpand_amount'] = 'Valor';
$lang['AdminBilling.invoices.headingexpand_paymenttype'] = 'Tipo de pagamento';
$lang['AdminBilling.transactions.applied_no_results'] = 'Essa transação não foi aplicada a nenhuma fatura.';
$lang['AdminBilling.transactions.headingexpand_appliedon'] = 'Aplicado em';
$lang['AdminBilling.transactions.headingexpand_amount'] = 'Valor';
$lang['AdminBilling.transactions.headingexpand_invoice'] = 'Fatura';
$lang['AdminBilling.transactions.no_results'] = 'Não há transações com esse status.';
$lang['AdminBilling.transactions.option_edit'] = 'Editar';
$lang['AdminBilling.transactions.category_returned'] = 'Devolvido';
$lang['AdminBilling.transactions.category_refunded'] = 'Reembolsado';
$lang['AdminBilling.transactions.category_pending'] = 'Pendente';
$lang['AdminBilling.transactions.category_error'] = 'Erro';
$lang['AdminBilling.transactions.category_voided'] = 'Anulado';
$lang['AdminBilling.transactions.category_declined'] = 'Recusado';
$lang['AdminBilling.transactions.category_approved'] = 'Aprovado';
$lang['AdminBilling.transactions.heading_options'] = 'Opções';
$lang['AdminBilling.transactions.heading_date'] = 'Data';
$lang['AdminBilling.transactions.heading_reference_id'] = 'Referência';
$lang['AdminBilling.transactions.boxtitle_transactions'] = 'Transações';
$lang['AdminBilling.transactions.page_title'] = 'Transações de faturamento';
$lang['AdminBilling.serviceinfo.cancellation_reason'] = 'Motivo do cancelamento: %1$s';
$lang['AdminBilling.serviceinfo.no_results'] = 'Esse serviço não tem detalhes.';
$lang['AdminBilling.services.field_actionsubmit'] = 'Enviar';
$lang['AdminBilling.services.action.field_client'] = 'Cliente:';
$lang['AdminBilling.services.action.push_to_client'] = 'Enviar para o cliente';
$lang['AdminBilling.services.action.field_action_type_none'] = 'Não cancelar';
$lang['AdminBilling.services.action.field_action_type_date'] = 'Data específica';
$lang['AdminBilling.services.action.field_action_type_term'] = 'Fim do prazo';
$lang['AdminBilling.services.action.schedule_cancellation'] = 'Cancelamento de cronograma';
$lang['AdminBilling.services.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminBilling.services.no_results'] = 'Não há serviços com esse status.';
$lang['AdminBilling.services.text_never'] = 'Nunca';
$lang['AdminBilling.services.category_scheduled_cancellation'] = 'Programado';
$lang['AdminBilling.services.category_in_review'] = 'Em análise';
$lang['AdminBilling.services.category_pending'] = 'Pendente';
$lang['AdminBilling.services.category_suspended'] = 'Suspenso';
$lang['AdminBilling.services.category_canceled'] = 'Cancelado';
$lang['AdminBilling.services.category_active'] = 'Ativo';
$lang['AdminBilling.services.confirm_delete'] = 'Tem certeza de que deseja excluir esse serviço?';
$lang['AdminBilling.services.option_delete'] = 'Excluir';
$lang['AdminBilling.services.option_manage'] = 'Gerenciar';
$lang['AdminBilling.services.heading_options'] = 'Opções';
$lang['AdminBilling.services.heading_datecanceled'] = 'Data do cancelamento';
$lang['AdminBilling.services.heading_datesuspended'] = 'Data da suspensão';
$lang['AdminBilling.services.heading_daterenews'] = 'Data de renovação';
$lang['AdminBilling.services.heading_dateadded'] = 'Data de adição';
$lang['AdminBilling.services.heading_term'] = 'Prazo';
$lang['AdminBilling.services.heading_label'] = 'Rótulo';
$lang['AdminBilling.services.heading_package'] = 'Pacote';
$lang['AdminBilling.services.heading_client'] = 'Cliente #';
$lang['AdminBilling.services.boxtitle_services'] = 'Serviços';
$lang['AdminBilling.services.page_title'] = 'Serviços de faturamento';
$lang['AdminBilling.quotationinvoices.invoices_no_results'] = 'Não há faturas associadas a essa cotação.';
$lang['AdminBilling.quotationinvoices.option_view'] = 'Ver';
$lang['AdminBilling.quotationinvoices.headingexpand_options'] = 'Opções';
$lang['AdminBilling.quotationinvoices.headingexpand_date_billed'] = 'Data do faturamento';
$lang['AdminBilling.quotationinvoices.headingexpand_paid'] = 'Pago';
$lang['AdminBilling.quotationinvoices.headingexpand_amount'] = 'Valor';
$lang['AdminBilling.quotationinvoices.headingexpand_invoice'] = 'Número da fatura';
$lang['AdminBilling.quotations.no_results'] = 'Não há cotações com esse status.';
$lang['AdminBilling.quotations.confirm_approve'] = 'Tem certeza de que deseja aprovar essa citação?';
$lang['AdminBilling.quotations.option_approve'] = 'Aprovar';
$lang['AdminBilling.quotations.option_invoice'] = 'Criar fatura';
$lang['AdminBilling.quotations.option_view'] = 'Ver';
$lang['AdminBilling.quotations.option_edit'] = 'Editar';
$lang['AdminBilling.quotations.heading_options'] = 'Opções';
$lang['AdminBilling.quotations.heading_date_expires'] = 'Data de expiração';
$lang['AdminBilling.quotations.heading_date_created'] = 'Data de criação';
$lang['AdminBilling.quotations.heading_total'] = 'Valor';
$lang['AdminBilling.quotations.heading_subtotal'] = 'Subtotal';
$lang['AdminBilling.quotations.heading_staff'] = 'Citado por';
$lang['AdminBilling.quotations.heading_title'] = 'Título';
$lang['AdminBilling.quotations.heading_client'] = 'Cliente #';
$lang['AdminBilling.quotations.heading_quotation'] = 'Citação #';
$lang['AdminBilling.quotations.boxtitle_quotations'] = 'Citações';
$lang['AdminBilling.quotations.page_title'] = 'Cotações de faturamento';
$lang['AdminBilling.invoices.no_results'] = 'Não há faturas com esse status.';
$lang['AdminBilling.invoices.duration_infinite'] = '∞';
$lang['AdminBilling.invoices.duration_finite'] = '%1$s vezes';
$lang['AdminBilling.invoices.term_year_plural'] = '%1$s anos';
$lang['AdminBilling.invoices.term_month_plural'] = '%1$s meses';
$lang['AdminBilling.invoices.term_week_plural'] = '%1$s semanas';
$lang['AdminBilling.invoices.term_day_plural'] = '%1$s dias';
$lang['AdminBilling.invoices.term_year'] = '%1$s ano';
$lang['AdminBilling.invoices.term_month'] = '%1$s mês';
$lang['AdminBilling.invoices.term_week'] = '%1$s semana';
$lang['AdminBilling.invoices.term_day'] = '%1$s dia';
$lang['AdminBilling.invoices.subtotal_w_tax'] = '%1$s +taxas';
$lang['AdminBilling.invoices.option_pay'] = 'Pagamento';
$lang['AdminBilling.invoices.option_view'] = 'Ver';
$lang['AdminBilling.invoices.option_edit'] = 'Editar';
$lang['AdminBilling.invoices.category_recurring'] = 'Recorrente';
$lang['AdminBilling.invoices.category_pending'] = 'Pendente';
$lang['AdminBilling.invoices.category_pastdue'] = 'Vencido';
$lang['AdminBilling.invoices.category_voided'] = 'Anulado';
$lang['AdminBilling.invoices.category_closed'] = 'Fechado';
$lang['AdminBilling.invoices.category_drafts'] = 'Rascunhos';
$lang['AdminBilling.invoices.category_open'] = 'Aberto';
$lang['AdminBilling.invoices.heading_count'] = 'Contagem';
$lang['AdminBilling.invoices.heading_duration'] = 'Duração';
$lang['AdminBilling.invoices.heading_term'] = 'Prazo';
$lang['AdminBilling.invoices.heading_options'] = 'Opções';
$lang['AdminBilling.invoices.heading_datedue'] = 'Data de vencimento';
$lang['AdminBilling.invoices.heading_datebilled'] = 'Data do faturamento';
$lang['AdminBilling.invoices.heading_dateclosed'] = 'Data de fechamento';
$lang['AdminBilling.invoices.heading_due'] = 'Devido';
$lang['AdminBilling.invoices.heading_paid'] = 'Pago';
$lang['AdminBilling.invoices.heading_amount'] = 'Valor';
$lang['AdminBilling.invoices.heading_client'] = 'Cliente #';
$lang['AdminBilling.invoices.heading_recurinvoice'] = 'Recorrente #';
$lang['AdminBilling.invoices.heading_invoice'] = 'Número da fatura';
$lang['AdminBilling.invoices.boxtitle_invoices'] = 'Faturas';
$lang['AdminBilling.invoices.page_title'] = 'Faturas de cobrança';
$lang['AdminBilling.managewidgets.text_author'] = 'Autor:';
$lang['AdminBilling.managewidgets.text_version'] = 'ver %1$s';
$lang['AdminBilling.managewidgets.text_widgets'] = 'Arraste os widgets da direita para a esquerda para adicioná-los à sua visão geral de faturamento, ou da esquerda para a direita para removê-los.';
$lang['AdminBilling.updatedashboard.text_layout'] = 'Selecione um layout abaixo para personalizar sua visão geral de faturamento.';
$lang['AdminBilling.index.action_batch'] = 'Lote de itens pendentes';
$lang['AdminBilling.index.action_printqueue'] = 'Itens pendentes de impressão';
$lang['AdminBilling.index.no_actions'] = 'Não há itens de ação pendentes.';
$lang['AdminBilling.index.heading_actions'] = 'Itens de ação';
$lang['AdminBilling.index.customize_dashboard'] = 'Personalizar a visão geral';
$lang['AdminBilling.index.manage_widgets'] = 'Gerenciar Widgets';
$lang['AdminBilling.index.page_title'] = 'Visão geral do faturamento';
$lang['AdminBilling.index.closed_parethesis'] = ')';
$lang['AdminBilling.index.open_parethesis'] = '(';
$lang['AdminBilling.!error.future_cancel_date'] = 'A data de cancelamento programada não pode ser anterior.';
$lang['AdminBilling.!error.invalid_passphrase'] = 'A frase secreta inserida é inválida.';
$lang['AdminBilling.!error.no_invoices_selected'] = 'Nenhuma fatura foi selecionada.';
$lang['AdminBilling.!success.services_pushed'] = 'Os serviços selecionados foram enviados com sucesso para o novo cliente.';
$lang['AdminBilling.!success.services_scheduled_uncancel'] = 'Os serviços selecionados não estão mais programados para serem cancelados.';
$lang['AdminBilling.!success.services_scheduled_cancel'] = 'Os serviços selecionados foram programados com sucesso para serem cancelados.';
$lang['AdminBilling.!success.invoices_marked_printed'] = 'As faturas selecionadas foram marcadas como impressas.';
$lang['AdminBilling.services.action.field_suspension_reason'] = 'Motivo da suspensão:';
$lang['AdminBilling.services.action.unsuspend'] = 'Não suspender';
$lang['AdminBilling.services.action.suspend'] = 'Suspender';
$lang['AdminBilling.!success.services_unsuspended'] = 'Os serviços selecionados foram suspensos com sucesso.';
$lang['AdminBilling.!success.services_suspended'] = 'Os serviços selecionados foram suspensos com sucesso.';
